changeset 1835:6d9dd19450b1 draft

(svn r2340) - Fix (Regression): [ 1203731 ] Signs don't work in multiplayer, unwanted remains of the _decode_parameters to _cmd_text move.
author Darkvater <Darkvater@openttd.org>
date Tue, 17 May 2005 18:50:07 +0000
parents cf4c15e04a89
children 8f8d84cb13a7
files signs.c
diffstat 1 files changed, 4 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/signs.c
+++ b/signs.c
@@ -136,17 +136,15 @@
  */
 int32 CmdRenameSign(int x, int y, uint32 flags, uint32 p1, uint32 p2)
 {
-	SignStruct *ss;
-
-	/* If GetDParam(0) != 0 means the new text for the sign is non-empty.
+	/* If _cmd_text != 0 means the new text for the sign is non-empty.
 	 * So rename the sign. If it is empty, it has no name, so delete it */
-	if (GetDParam(0) != 0) {
+	if (_cmd_text != NULL) {
 		/* Create the name */
 		StringID str = AllocateName(_cmd_text, 0);
 		if (str == 0) return CMD_ERROR;
 
 		if (flags & DC_EXEC) {
-			ss = GetSign(p1);
+			SignStruct *ss = GetSign(p1);
 
 			/* Delete the old name */
 			DeleteName(ss->str);
@@ -166,7 +164,7 @@
 		}
 	} else { /* Delete sign */
 		if (flags & DC_EXEC) {
-			ss = GetSign(p1);
+			SignStruct *ss = GetSign(p1);
 
 			/* Delete the name */
 			DeleteName(ss->str);